@@ -3,7 +3,7 @@
 module ActiveStorage
   # Representation of a single attachment to a model.
   class Attached::One < Attached
-    delegate_missing_to :attachment
+    delegate_missing_to :attachment, allow_nil: true
 
     # Returns the associated attachment record.
     #
@@ -29,7 +29,8 @@ module ActiveStorage
     #   person.avatar.attach(avatar_blob) # ActiveStorage::Blob object
     def attach(attachable)
       if record.persisted? && !record.changed?
-        record.update(name => attachable)
+        record.public_send("#{name}=", attachable)
+        record.save
       else
         record.public_send("#{name}=", attachable)
       end
@@ -37,7 +38,7 @@ module ActiveStorage
 
     # Returns +true+ if an attachment has been made.
     #
-    #   class User < ActiveRecord::Base
+    #   class User < ApplicationRecord
     #     has_one_attached :avatar
     #   end
     #
